@@ -5,6 +5,8 @@ EventTypes = Literal[
     "AUDIO_STREAM_ENABLED",
     "PARTICIPANT_LEFT",
     "AGENT_STARTED",
+    "ON_SPEECH_IN",
+    "ON_SPEECH_OUT",
 ]
 
 T = TypeVar('T')
